@@ -14,7 +14,7 @@ extends 'AnyEvent::Net::Curl::Queued';
 
 use YADA::Worker;
 
-our $VERSION = '0.038'; # VERSION
+our $VERSION = '0.039'; # VERSION
 
 # serious DWIMmery ahead!
 around qw(append prepend) => sub {
@@ -43,17 +43,12 @@ around qw(append prepend) => sub {
         }
 
         for my $url (@url) {
-            $self->$orig(
-                sub {
-                    YADA::Worker->new({
-                        initial_url => $url,
-                        %init,
-                    })
-                }
-            );
+            my %copy = %init;
+            $copy{initial_url} = $url;
+            $orig->($self => sub { YADA::Worker->new(\%copy) });
         }
     } else {
-        $self->$orig(@_);
+        $orig->($self => @_);
     }
 
     return $self;
@@ -77,7 +72,7 @@ YADA - "Yet Another Download Accelerator": alias for AnyEvent::Net::Curl::Queued
 
 =head1 VERSION
 
-version 0.038
+version 0.039
 
 =head1 SYNOPSIS
 
